package com.ai.android.ExerciseSystemIntents;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.ComponentName;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

public class MainActivity extends ManagedDialogsActivity 
implements IStringPrompterCallBack
{
	
	private final static String L = "MainActivity";
	
	private GenericManagedAlertDialog gmad = 
		new GenericManagedAlertDialog(this,1,"Simple Sample Alert");
	
	private GenericPromptDialog gmpd = 
		new GenericPromptDialog(this,2,"Your text goes here");
	
	//Initialize this in onCreateOptions
	Menu myMenu = null;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.main);
        this.registerDialogs();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) 
    {
    	//call the parent to attach any system level menus
    	super.onCreateOptionsMenu(menu);
    	
    	this.myMenu = menu;

    	MenuInflater mi = this.getMenuInflater();
    	mi.inflate(R.menu.main_menu,menu);
    	
    	return true;
    }
    
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item) 
    {
    	try
    	{
    		handleMenus(item);
    	}
    	catch(Throwable t)
    	{
    		Log.d(this.L,t.getMessage(),t);
    		throw new RuntimeException("error",t);
    	}
    	//should return true if the menu item
    	//is handled
    	return true;
    	
    	//If it is not our menu item
    	//let the base class handle it
        //return super.onOptionsItemSelected(item);

    }
    private void handleMenus(MenuItem item)
    {
		this.appendMenuItemText(item);
		if (item.getItemId() == R.id.menu_clear)
		{
			this.emptyText();
		}
		else if (item.getItemId() == R.id.menu_dial)
		{
			this.dial();
		}
		else if (item.getItemId() == R.id.menu_testPick)
		{
			IntentsUtils.invokePick(this);
		}
		else if (item.getItemId() == R.id.menu_testGetContent)
		{
			IntentsUtils.invokeGetContent(this);
		}
		else if (item.getItemId() == R.id.menu_show_browser)
		{
			//IntentsUtils.invokeWebBrowser(this);
			//IntentsUtils.invokeWebSearch(this);
			//IntentsUtils.dial(this);
	    	//this.exercisePrompt();
	    	//this.exerciseAlertDialog();
	    	this.exerciseDialogRegistry();
			IntentsUtils.tryOneOfThese(this);
		}
		else if (item.getItemId() == R.id.menu_simple_alert)
		{
	    	this.exerciseSimpleAlertDialog();
		}
		else if (item.getItemId() == R.id.menu_simple_prompt)
		{
	    	this.exerciseSimplePromptDialog();
		}
    }
    
    private TextView getTextView()
    {
       	TextView tv = 
       		(TextView)this.findViewById(R.id.textViewId);
       	return tv;
    }
    public void appendText(String text)
    {
       	TextView tv = 
       		(TextView)this.findViewById(R.id.textViewId);
       	tv.setText(tv.getText() + text);
    }
    public void appendMenuItemText(MenuItem menuItem)
    {
    	String title = menuItem.getTitle().toString();
       	TextView tv = 
       		(TextView)this.findViewById(R.id.textViewId);
       	tv.setText(tv.getText() + "\n" + title + ":" + menuItem.getItemId());
    }
    private void emptyText()
    {
       	TextView tv = 
       		(TextView)this.findViewById(R.id.textViewId);
       	tv.setText("");
    }
    private void dial()
    {
    	Intent intent = new Intent(Intent.ACTION_DIAL);
    	intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
    	this.startActivity(intent);
    }
    private void invokeContacts()
    {
    	Intent intent = new Intent(Intent.ACTION_VIEW);
    	intent.setComponent(new ComponentName("com.android.contacts","com.android.contacts.DialtactsContactsEntryActivity"));
    	this.startActivity(intent);
    }
    private void showAllApps()
    {
    	Log.d("MainActivity", "hello this is a debug message");
    	System.out.println("hello.....");
    	Intent intent = new Intent(Intent.ACTION_ALL_APPS);
    	intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
    	this.startActivity(intent);
    }
    private void dialWithNumber(String tel)
    {
    	String  telUriString = "tel:" + tel;
    	Log.d(L, telUriString);
    	Intent intent = new Intent(Intent.ACTION_DIAL);
    	intent.setData(Uri.parse(telUriString));
    	intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
    	this.startActivity(intent);
    }
    
	public void promptCallBack(String promptedString, 
			int buttonPressed, //which button was pressed 
			int actionId) //To support multiple prompts
	{
		if (buttonPressed == IStringPrompterCallBack.OK_BUTTON)
		{
			this.appendText("\nprompted string is:" + promptedString);
		}
		else
		{
			this.appendText("\nCancel has been pressed instead");
		}
	}
	private void exercisePrompt()
	{
		Alert.Prompt(this,"Please enter a filename", this,1);
	}
	
	private int alertDemoCounter=0;
	
    //set this 
    private String dynamicMessage = "Initial Message";
    private Dialog createAlertDialog()
    {
    	return Alert.createAlertDialog(dynamicMessage, this);
    }
    
    private void prepareAlertDialog(Dialog d)
    {
    	AlertDialog ad = (AlertDialog)d;
    	ad.setMessage(dynamicMessage);
    }
    
    private void exerciseSimpleAlertDialog()
    {
    	this.gmad.show();
    }
    private void exerciseSimplePromptDialog()
    {
    	this.gmpd.show();
    }
    private void exerciseAlertDialog()
    {
    	this.dynamicMessage="Dynamic Message:" + alertDemoCounter++;
    	showDialog(this.gmad.getDialogId());
    }
    
    
    protected void registerDialogs()
    {
    	registerDialog(gmad);
    	registerDialog(this.gmpd);
    }
    private void exerciseDialogRegistry()
    {
    	gmad.setAlertMessage("some message:" + this.alertDemoCounter++);
    	gmad.show();
    }

    protected void onActivityResult(int requestCode
    	,int resultCode
    	,Intent outputIntent)
    {
    	super.onActivityResult(requestCode, resultCode, outputIntent);
    	IntentsUtils.parseResult(this, requestCode, resultCode, outputIntent);
    }

    
}//eof-class